#
# spec file for package python-slack-sdk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-slack-sdk
Version:        3.31.0
Release:        1.1
Summary:        Python SDKs for the Slack API
License:        MIT
URL:            https://github.com/slackapi/python-slack-sdk
Source:         https://github.com/slackapi/python-slack-sdk/archive/v%{version}.tar.gz#/slack-sdk-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Obsoletes:      python-slackclient < %{version}
Provides:       python-slackclient = %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module itsdangerous}
BuildRequires:  %{python_module moto}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sqlalchemy}
BuildRequires:  %{python_module websockets}
# /SECTION
%python_subpackages

%description
The Slack platform offers several APIs to build apps. Each Slack API delivers
part of the capabilities from the platform, so that you can pick just those
that fit for your needs. This SDK offers a corresponding package for each of
Slack’s APIs. They are small and powerful when used independently, and work
seamlessly when used together, too.

%prep
%autosetup -p1 -n python-slack-sdk-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Tests needs to be importable
export PYTHONPATH=$(pwd)
# No flask_sockets in Tumbleweed; TestRTMClient requires network
# test_issue_1441_mixing_user_and_bot_installations broken upstream
%pytest --ignore-glob '*/socket_mode/*' -k 'not (TestRTMClient or test_issue_1441_mixing_user_and_bot_installations)' tests

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/slack
%{python_sitelib}/slack_sdk
%{python_sitelib}/slack_sdk-%{version}.dist-info

%changelog
* Tue Aug  6 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.31.0:
  * feat: add new conversations.externalInvitePermissions.set API
  * feat: add team.externalTeams.disconnect
  * fix: redact bot_access_tokens from the debug logs of socket mode
  * feat: add team.externalTeams.list
  * Add canvases APIs and users.discoverableContacts.lookup API
  * Added deprecation warnings to Steps from Apps methods
  * Fix base url according to official documentation
  * Fix AttributeError on SocketModeClient.is_connected (aiohttp) when
    enabling debug-level logging
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 3.27.2:
  * #1498 Fix #1496 Async client uses blocking call when
    uploading file with v
  * #1492 Fix #1468 `RichTextElement.elements` items are never
    promoted to a proper Python object type
* Wed Mar  6 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.27.1:
  * #1459 Fix #1458 internal error within aiohttp-based socket mode
    client - Thanks @seratch @jhofeditz
  * #1450 #1452 Add "slack_file" properties to "image" blocks/elements
    under slack_sdk.models - Thanks @seratch
  * #1466 Fix #1462 websocket_client-based SocketModeClient does not
    reconnect after a DNS outage - Thanks @ktindall-godaddy @seratch
  * #1463 Unpin moto, and support moto 5.0 changes - Thanks
    @s-t-e-v-e-n-k
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 3.26.2:
  * #1447 #1446 aiohttp based socket_mode failed to reconnect and
    enter a broken state
  * #1436 Configuring with pyproject.toml
  * #1443 Update run_*.sh scripts to align with the contributor
  * #1445 Replace Flask-Sockets with aiohttp for testing
  * #1448 Fix broken links to modal documentation
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 3.26.1:
  * #1441 #1442 Built-in InstallationStores fail to resolve a
    valid bot token when both bot and user-only installations co-
    exist in database tables - Thanks @kulmatitskiy @seratch
  * #1440 Fix a bug on the aiohttp-based Socket Mode client's
    exception handling - Thanks @ifmcnichols
  * #1438 Add new `force` argument to `conversations.invite` API
    method - Thanks @filmaj
  * #1435 Enable testing for Python 3.12 and PyPy 3.10 on CI -
  * #1432 Add functions.completeSuccess/Error APIs for remote
    functions - Thanks @seratch @WilliamBergamin
  * #1433 Add RichTextBlock to Block.parse() targets - Thanks
    @seratch
  * #1430 Fix #1427 Add apps.manifest.* & tooling.tokens.rotate
    API support - Thanks @seratch
  * #1431 Fix #1428 Add rich_text classes to slack_sdk.models
    module - Thanks @seratch @tj-smith47
  * #1425 Fix #1424 Add file input block element support - Thanks
    @seratch
  * #1423 Fix #1421 Update SlackApiError exception handling for
    web client - Thanks @vinceta
  * #1418 Add new arguments to admin.users.list API method -
    Thanks @seratch
  * #1409 Make next_cursor extraction logic even more robust (ref
    [#1407]) - Thanks @seratch
  * #1406 Add `RichTextInputElement` to `slack_sdk.models` -
  * #1408 Update `files.upload` v2 method in correspondence with
    server-side changes - Thanks @seratch
  * Since this version, developers no longer need `files:read`
    permission for `files_upload_v2` method. To learn more about
    `files_upload_v2`, please refer to v3.19.0 release notes:
    https://github.com/slackapi/python-slack-
    sdk/releases/tag/v3.19.0
  * #1398 Add `admin.*` APIs for managing automation platform
    apps - Thanks @seratch
  * #1399 Add `workflow_button` block element to the
    `slack_sdk.models` package - Thanks @seratch
  * #1362 Add `metadata` argument support to Incoming Webhooks -
    Thanks @seratch
  * #1368 Add cursor based pagination to `team.accessLogs` API -
    Thanks @seratch
  * #1380 Fix #1379 websocket-client socket mode client doesn't
    handle reconnects properly - Thanks @seratch @leifwalsh
  * #1367 #1364 #1378 Add built in server error retry handlers -
    Thanks @digitalnomd
  * #1372 `ServerErrorRetryHandler`, renaming `_can_retry_async`
  - > `_can_retry` - Thanks @maximkir-fl
  * #1374 Fix #1369 `ImageBlock`'s title parsing fails when given
    a string - Thanks @seratch @kezabelle
  * #1366 Add `author_subname` to `attachment` model class -
    Thanks @seratch
  * #1365 Add `create_tables()` to `SQLAlchemyOAuthStateStore` -
    Thanks @raphaelhuefner
  * #1387 Mark `stars.*` API methods as deprecated -  Thanks
    @seratch
  * #1375 Update GitHub Action steps to use Node 16 - Thanks
    @zimeg
  * #1376 Use `codecov/codecov-action@v3` to upload code coverage
  - Thanks @zimeg
* Thu Jun  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.21.3:
  * #1361 Fix #1356 files_upload_v2 filename required even though content
    provided
  * #1354 Fix a bug where SQLAlchemy based InstallationStore is missing
    client_id in queries
  * #1352 Improve the default OAuth page content renderer not to embed
    external parameters as-is
  * Update Audit Logs API response class to have newly added properties
  * #1349 Add five admin API supports to Web API clients (admin.roles.*,
    admin.conversations.convertToPublic, admin.conversations.lookup)
  * #1345 Add team parameter support to the authorize URL generators
  * #1343 Fix #1342 files_upload_v2 fails to share files in a channel
  * #1334 Fix #1333 Enable using RetryHandler for 200 OK response patterns
  * #1335 Fix #1327 OAuth module: SQLAlchemy v2 compatibility
  * #1311 Fix #1310 Add admin.conversations.bulk{Archive|Delete|Move} API
    method support
  * #1332 Fix #1322 Remove file_annotation parameter from chat.postMessage
    method
  * #1317 Add include_categories to emoji.list API args
- Switch to pyproject macros.
* Fri Jan  6 2023 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Change log is upto date with the version.
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.19.5
  [#1303] Fix #1302 by updating the warning logs in WebClient to be consistent with Node SDK - Thanks @mar3mar3
  [#1307] Fix #1304 ssl_context is not passed from async web_client to aiohttp socket client - Thanks @seratch @giwrgos-skouras
  [#1308] Fix #1305 by fixing pagination with async for syntax - Thanks @seratch @WilliamYuhangLee
- Update to v3.19.4
  [#1301] Fix #1297 Building user_auth_blocks with slack_sdk.models class objects for chat.unfurl API call fails - Thanks @seratch @injust
- Update to v3.19.3
  [#1288] Add datetimepicker, url, email, number block elements - Thanks @WilliamBergamin
  [#1294] Fix #1292 files_upload_v2 does not work with io.BytesIO file parameters - Thanks @seratch
  [#1290] Update RTM API documents - Thanks @ryan-aldaz
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.19.2
  [#1282] Add request_file_info arg to files_upload_v2 method - Thanks @seratch @eddyg
  [#1278] Improve clarity of 'content' error message for files_upload_v2 - Thanks @eddyg
  [#1283] Improve typing when using 'get' on an API response - Thanks @eddyg
  [#1284] Add Python 3.11 support - Thanks @seratch
  [#1281] Fix selected_option type hint - Thanks @taekop
  All issues/pull requests: https://github.com/slackapi/python-slack-sdk/milestone/71?closed=1
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.19.1
  Improve WebClient#files_upload_v2() to use given filename as the default title value - Thanks @seratch @mattpr
- Update to 3.19.0
  [#1272] Add files.upload v2 support, which resolves #1191 #1165 - Thanks @seratch
- Update to 3.18.5
  [#1271] Add more revert to #1269 - Thanks @seratch @yardensachs
- Update to 3.18.4
  [#1264] Fix retry_handlers type hint in AsyncBaseClient - Thanks @ronyb29
  [#1265] #1266 Add selected_time (timepicker) to ViewStateValue class - Thanks @rei-0
  [#1270] Add include_all_metadata to conversations.replies API arguments - Thanks @seratch
  [#1269] Adjust the logic added by #1246 - Thanks @seratch @eddyg
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.18.3
  Changes
  * #1262 Fix #1261 blocks/attachments as str for chat. API calls should be clearly supported - Thanks @seratch
  * #1259 Fix #1258 Tuple value for blocks argument does not work for Web API calls - Thanks @tommasobertoni
  * #1253 Minor update: max elements in ActionsBlock to 25 - Thanks @YSaxon
  * #1249 #1251 Add in timezone property for timepicker element - Thanks @hello-ashleyintech
* Wed Aug  3 2022 Steve Kowalik <steven.kowalik@suse.com>
- Inital release, 3.18.1
